@@ -13,7 +13,9 @@ import aicloud.settings as settings
 
 # root = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 root = os.path.abspath(os.path.dirname(os.getcwd()))
+sdk_root = os.path.join(os.getcwd(), 'sdk')
 sys.path.append(root)
+sys.path.append(sdk_root)
 logging.basicConfig(level=logging.DEBUG, format="%(asctime)s %(name)s:%(levelname)s:%(message)s",
                     datefmt="%Y-%M-%d %H:%M:%S")
 
